# This file is generated by make.paws. Please do not edit here.
#' @importFrom paws.common new_handlers new_service set_config merge_config
NULL

#' Amazon EventBridge Scheduler
#'
#' @description
#' Amazon EventBridge Scheduler is a serverless scheduler that allows you
#' to create, run, and manage tasks from one central, managed service.
#' EventBridge Scheduler delivers your tasks reliably, with built-in
#' mechanisms that adjust your schedules based on the availability of
#' downstream targets. The following reference lists the available API
#' actions, and data types for EventBridge Scheduler.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- eventbridgescheduler(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- eventbridgescheduler()
#' svc$create_schedule(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[=eventbridgescheduler_create_schedule]{create_schedule} \tab Creates the specified schedule\cr
#'  \link[=eventbridgescheduler_create_schedule_group]{create_schedule_group} \tab Creates the specified schedule group\cr
#'  \link[=eventbridgescheduler_delete_schedule]{delete_schedule} \tab Deletes the specified schedule\cr
#'  \link[=eventbridgescheduler_delete_schedule_group]{delete_schedule_group} \tab Deletes the specified schedule group\cr
#'  \link[=eventbridgescheduler_get_schedule]{get_schedule} \tab Retrieves the specified schedule\cr
#'  \link[=eventbridgescheduler_get_schedule_group]{get_schedule_group} \tab Retrieves the specified schedule group\cr
#'  \link[=eventbridgescheduler_list_schedule_groups]{list_schedule_groups} \tab Returns a paginated list of your schedule groups\cr
#'  \link[=eventbridgescheduler_list_schedules]{list_schedules} \tab Returns a paginated list of your EventBridge Scheduler schedules\cr
#'  \link[=eventbridgescheduler_list_tags_for_resource]{list_tags_for_resource} \tab Lists the tags associated with the Scheduler resource\cr
#'  \link[=eventbridgescheduler_tag_resource]{tag_resource} \tab Assigns one or more tags (key-value pairs) to the specified EventBridge Scheduler resource\cr
#'  \link[=eventbridgescheduler_untag_resource]{untag_resource} \tab Removes one or more tags from the specified EventBridge Scheduler schedule group\cr
#'  \link[=eventbridgescheduler_update_schedule]{update_schedule} \tab Updates the specified schedule
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname eventbridgescheduler
#' @export
eventbridgescheduler <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  config <- merge_config(
    config,
    list(
      credentials = credentials,
      endpoint = endpoint,
      region = region
    )
  )
  svc <- .eventbridgescheduler$operations
  svc <- set_config(svc, config)
  return(svc)
}

# Private API objects: metadata, handlers, interfaces, etc.
.eventbridgescheduler <- list()

.eventbridgescheduler$operations <- list()

.eventbridgescheduler$metadata <- list(
  service_name = "eventbridgescheduler",
  endpoints = list("^(us|eu|ap|sa|ca|me|af|il|mx)\\-\\w+\\-\\d+$" = list(endpoint = "scheduler.{region}.amazonaws.com", global = FALSE), "^cn\\-\\w+\\-\\d+$" = list(endpoint = "scheduler.{region}.amazonaws.com.cn", global = FALSE), "^us\\-gov\\-\\w+\\-\\d+$" = list(endpoint = "scheduler.{region}.amazonaws.com", global = FALSE), "^us\\-iso\\-\\w+\\-\\d+$" = list(endpoint = "scheduler.{region}.c2s.ic.gov", global = FALSE), "^us\\-isob\\-\\w+\\-\\d+$" = list(endpoint = "scheduler.{region}.sc2s.sgov.gov", global = FALSE), "^eu\\-isoe\\-\\w+\\-\\d+$" = list(endpoint = "scheduler.{region}.cloud.adc-e.uk", global = FALSE), "^us\\-isof\\-\\w+\\-\\d+$" = list(endpoint = "scheduler.{region}.csp.hci.ic.gov", global = FALSE)),
  service_id = "Scheduler",
  api_version = "2021-06-30",
  signing_name = "scheduler",
  json_version = "1.1",
  target_prefix = ""
)

.eventbridgescheduler$service <- function(config = list(), op = NULL) {
  handlers <- new_handlers("restjson", "v4")
  new_service(.eventbridgescheduler$metadata, handlers, config, op)
}
